.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. TotalDepth Technical Notes.

###############################
Technical Notes
###############################

This collect together various technical descriptions of how TotalDepth solves certain problems.

Contents:

.. toctree::
    :maxdepth: 3
   
    performance
    LIS_indexing
    LIS_processing
    RP66V1_indexing
    RP66V1_processing
    plotting
    data_quality
    saas
    process_monitoring
    gnuplot
